@@ -1,6 +1,6 @@
 # ABSTRACT: ArangoDB Collection object
 package Arango::Tango::Collection;
-$Arango::Tango::Collection::VERSION = '0.016';
+$Arango::Tango::Collection::VERSION = '0.017';
 use warnings;
 use strict;
 
@@ -96,11 +96,13 @@ sub _new {
 }
 
 sub bulk_import {
-    my ($self, $documents) = @_;
+    my ($self, $documents, %options) = @_;
+    $options{type} ||= "list";
     return $self->{arango}->_api( bulk_import_list => {
         database => $self->{database},
         collection => $self->{name},
-        body => $documents
+        _body => $documents,
+        _url_parameters => \%options
     })
 }
 
@@ -112,13 +114,13 @@ sub document_paths {
 sub create_document {
     my ($self, $body) = @_;
     die "Arango::Tango | Refusing to store undefined body" unless defined($body);
-    return $self->{arango}->_api( create_document => { database => $self->{database}, collection => $self->{name}, body => $body})
+    return $self->{arango}->_api( create_document => { database => $self->{database}, collection => $self->{name}, _body => $body})
 }
 
 sub replace_document {
     my ($self, $key, $body) = @_;
     die "Arango::Tango | Refusing to store undefined body" unless defined($body);
-    return $self->{arango}->_api( replace_document => { database => $self->{database}, collection => $self->{name}, key => $key, body => $body})
+    return $self->{arango}->_api( replace_document => { database => $self->{database}, collection => $self->{name}, key => $key, _body => $body})
 }
 
 sub get_access_level {
@@ -151,7 +153,7 @@ Arango::Tango::Collection - ArangoDB Collection object
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 USAGE
 
@@ -305,7 +307,7 @@ Alberto Simões <ambs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2022 by Alberto Simões.
+This software is copyright (c) 2019-2023 by Alberto Simões.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
